@@ -1,10 +1,14 @@
 #' Gets or creates a `cachem` object for use with other functions.
 #'
 #' @param cache The path to an existing directory to use for caching.
-#'   If `NULL` (default) uses the current path, using [here::here()].
 #'
-#'   For advanced use, also accepts (and passes on) an existing
-#'   `cachem` object. If so, all other parameters are ignored.
+#'   If `NULL` (default) uses a folder called "cache" in the current
+#'   path, using [here::here()]. The folder is created if it does not
+#'   already exist.
+#'
+#'   **Advanced:** if an existing `cachem` object is provided, all other
+#'   parameters are ignored and the object is passed on as is. This
+#'   functionality is primarily used internally or for testing.
 #' @inheritParams interpret_cache_type
 #'
 #' @return A [cachem::cache_disk()] object.
@@ -19,7 +23,8 @@ file_cache <- function(cache = NULL, type = NULL, ext_prefix = "cache_") {
   }
 
   if (is.null(cache)) {
-    cache <- here::here()
+    cache <- here::here("cache")
+    if (!dir.exists(cache)) dir.create(cache)
   } else if (!is.character(cache) || !dir.exists(cache)) {
     stop(
       "`cache` must be an existing cache or the path to an existing directory."
